@@ -1,11 +1,15 @@
 import argparse
+import os
 import sys
 from pathlib import Path
 from typing import Text
 
+import requests
+
 config_location = Path().home() / ".ipython/nbextensions/jupyter-cogram"
 token_file_name = "cogram_auth_token"
 log_file_name = "cogram_access_log"
+backend_url = os.environ.get("BACKEND_URL", "https://api.cogram.ai")
 
 
 def install_token(token: Text) -> None:
@@ -27,6 +31,18 @@ def add_log_file() -> None:
         p.touch()
 
 
+def set_installed_flag(auth_token: Text) -> None:
+    from urllib.parse import urljoin
+
+    url = urljoin(backend_url, "setInstalled")
+
+    # noinspection PyBroadException
+    try:
+        requests.post(url, json={"auth_token": auth_token}, timeout=10)
+    except:
+        pass
+
+
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="Set your Cogram API token")
     parser.add_argument(
@@ -48,6 +64,7 @@ if __name__ == "__main__":
     # noinspection PyBroadException
     try:
         install_token(token)
+        set_installed_flag(token)
         add_log_file()
     except Exception as e:
         print("⚠️  Could not install token:\n{e}")
