@@ -14,6 +14,7 @@ from pkg_resources import parse_version
 
 # noinspection PyProtectedMember
 from pkg_resources._vendor.packaging.version import Version
+from tornado.httputil import HTTPServerRequest
 
 import jupyter_cogram
 
@@ -109,12 +110,16 @@ def fetch_token(loc: Path = config_location) -> Optional[Text]:
     return fname.read_text().strip()
 
 
-def post_auth_token(token: Text) -> requests.Response:
+def post_auth_token(token: Text, log_launch: bool = False) -> requests.Response:
     url = f"{backend_url}/{check_token_endpoint}"
     logger.debug(f"Posting auth token to {url}. Token: {token}")
     return requests.post(
         url,
-        json={"auth_token": token},
+        json={
+            "auth_token": token,
+            "version": jupyter_cogram.__version__,
+            "log_launch": log_launch,
+        },
     )
 
 
@@ -203,6 +208,19 @@ def fetch_suggestion_code(
         raise ValueError(json.dumps(error_dict))
 
 
+def bool_arg(request: HTTPServerRequest, name: Text, default: bool = False) -> bool:
+    args = request.query_arguments.get(name, [])
+    if not args:
+        return default
+
+    arg = args[0]
+
+    if isinstance(arg, (bytes, bytearray)):
+        arg = arg.decode()
+
+    return arg.lower() == "true"
+
+
 class JupyterCogramHandler(IPythonHandler):
     def __init__(self, application, request, **kwargs):
         super(JupyterCogramHandler, self).__init__(application, request, **kwargs)
@@ -278,9 +296,12 @@ class JupyterCogramTokenHandler(IPythonHandler):
         logger.debug(f"Receiving token fetch request")
         token = fetch_token()
         logger.debug(f"Have fetched token {token}")
+
+        log_launch = bool_arg(self.request, "log_launch")
+
         if token is not None:
             logger.debug(f"Checking if token is valid against API: {token}")
-            token_valid = post_auth_token(token)
+            token_valid = post_auth_token(token, log_launch=log_launch)
         else:
             token_valid = False
 
